-- name: [CS] Toothless + Offsprings
-- description: It's the unholy offspring of lightning and death itself! Or just Toothless \nthe Night Fury.\nAlso includes Toothless's offsprings from HTTYD3/Homecoming: Dart, Pouncer and Ruffrunner the Night Lights as a bonus!\n\nToothless model from \nDreamWorks Dragons: Wild Skies\n\nDart, Pouncer and Ruffrunner models from School of Dragons\n\nMod by: \\#19f505\\MrMarco1003\n\n\\#ff7777\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
]]

local TEXT_MOD_NAME = "Toothless + Offsprings"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

-- Toothless

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("toothless_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("toothless_icon") -- Located in "textures"

-- All Located in "sound"
local VOICETABLE_TOOTHLESS = {
    [CHAR_SOUND_OKEY_DOKEY] = 'ToothlessStartGame.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'ToothlessStartLevel.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'ToothlessPunchYah.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'ToothlessPunchWah.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'ToothlessPunchHoo.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'ToothlessJump1.ogg', 'ToothlessJump2.ogg', 'ToothlessJump3.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = 'ToothlessDoubleJump.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'ToothlessTripleYahoo.ogg', 'ToothlessTripleWaha.ogg', "ToothlessTripleYippee.ogg"}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'ToothlessBonkUh.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'ToothlessUh2.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'ToothlessUh2.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'ToothlessTripleLand.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = 'ToothlessLongJump.ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'ToothlessBonkDoh.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'ToothlessGrabLedge.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'ToothlessClimbLedge.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'ToothlessFalling.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'ToothlessTwirlBounce.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'ToothlessGroundPound.ogg', 
	[CHAR_SOUND_HRMM] = 'ToothlessLift.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = 'ToothlessStarGet.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'ToothlessThrowBowser.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'ToothlessDamaged.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'ToothlessPanting.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'ToothlessOnFire.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'ToothlessTired.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'ToothlessYawning.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'ToothlessMute.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'ToothlessMute.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'ToothlessDreaming.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'ToothlessCoughing.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'ToothlessCoughing.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'ToothlessCoughing.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'ToothlessDyingDamage.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'ToothlessDrowning.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'ToothlessMammaMia.ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_CHAR = {
    normal = smlua_model_util_get_id("toothless_capnormal_geo"),
    wing = smlua_model_util_get_id("toothless_wingcap_geo"),
    metal = smlua_model_util_get_id("toothless_metalcap_geo"),
}

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "6D1518", -- Tail Fin
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "ffffff",
    [SKIN]   = "1B1D21", -- Skin colour
    [CAP]    = "ffffff",
}


-- All Located in "textures"
local healthToothless = {
    label = {
        left = get_texture_info("LeftHealth_Toothless"),
        right = get_texture_info("RightHealth_Toothless"),
    },
     pie = {
        [1] = get_texture_info("ToothlessPie1"),
        [2] = get_texture_info("ToothlessPie2"),
        [3] = get_texture_info("ToothlessPie3"),
        [4] = get_texture_info("ToothlessPie4"),
        [5] = get_texture_info("ToothlessPie5"),
        [6] = get_texture_info("ToothlessPie6"),
        [7] = get_texture_info("ToothlessPie7"),
        [8] = get_texture_info("ToothlessPie8"),
    }
}


--[[
    Note: If there are some functionalities you don't care
    to add such as palettes, you can freely remove the function
    for it, the only function you require is character_add
]]

local CSloaded = false
local function on_character_select_load()
    CT_CHAR = _G.charSelect.character_add("Toothless", {"The unholy offspring of lightning and death itself!", "Toothless from How to Train Your Dragon movies", "is an main dragon, who was trained by", "Hiccup Horrendous Haddock III in the first movie.", "He may be cute, but he sure is also dangerous!", "So watch out Bowser, Koopas and Goombas!", "Model from DreamWorks Dragons: Wild Skies"}, "MrMarco1003", {r = 181, g = 5, b = 5}, E_MODEL_CUSTOM_MODEL, CT_MARIO, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_TOOTHLESS)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHAR, healthToothless)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_TOOTHLESS then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_TOOTHLESS then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)

-- Dart

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("dart_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("dart_icon") -- Located in "textures"

-- All Located in "sound"
local VOICETABLE_DART = {
    [CHAR_SOUND_OKEY_DOKEY] = 'DartStartGame.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'DartStartLevel.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'DartPunchYah.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'DartPunchWah.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'DartPunchHoo.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'DartJump1.ogg', 'DartJump2.ogg', 'DartJump3.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = 'DartDoubleJump.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'DartTripleYahoo.ogg', 'DartTripleWaha.ogg', "DartTripleYippee.ogg"}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'DartBonkUh.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'DartUh2.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'DartUh2.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'DartTripleLand.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = 'DartLongJump.ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'DartBonkDoh.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'DartGrabLedge.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'DartClimbLedge.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'DartFalling.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'DartTwirlBounce.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'DartGroundPound.ogg', 
	[CHAR_SOUND_HRMM] = 'DartLift.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = 'DartStarGet.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'DartThrowBowser.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'DartDamaged.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'DartPanting.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'DartOnFire.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'DartTired.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'DartYawning.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'ToothlessMute.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'ToothlessMute.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'DartDreaming.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'DartCoughing.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'DartCoughing.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'DartCoughing.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'DartDyingDamage.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'DartDrowning.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'DartMammaMia.ogg' -- Booted out of level
}

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "ffffff",
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "ffffff",
    [SKIN]   = "535861", -- Skin colour
    [CAP]    = "ffffff",
}


--[[
    Note: If there are some functionalities you don't care
    to add such as palettes, you can freely remove the function
    for it, the only function you require is character_add
]]

local CSloaded = false
local function on_character_select_load()
    CT_CHAR = _G.charSelect.character_add("Dart", {"One of Toothless's kids!", "Dart is the only girl of the three siblings.", "Model from School of Dragons"}, "MrMarco1003", {r = 71, g = 155, b = 187}, E_MODEL_CUSTOM_MODEL, CT_MARIO, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_DART)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHAR, healthToothless)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)

-- Ruffrunner

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("ruffrunner_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("ruffrunner_icon") -- Located in "textures"

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "ffffff",
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "ffffff",
    [SKIN]   = "535861", -- Skin colour
    [CAP]    = "ffffff",
}


--[[
    Note: If there are some functionalities you don't care
    to add such as palettes, you can freely remove the function
    for it, the only function you require is character_add
]]

local CSloaded = false
local function on_character_select_load()
    CT_CHAR = _G.charSelect.character_add("Ruffrunner", {"One of Toothless's kids!", "Ruffrunner is a boy Night Light.", "Model from School of Dragons"}, "MrMarco1003", {r = 74, g = 195, b = 140}, E_MODEL_CUSTOM_MODEL, CT_MARIO, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_DART)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHAR, healthToothless)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)

-- Pouncer

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("pouncer_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("pouncer_icon") -- Located in "textures"

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "ffffff",
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "ffffff",
    [SKIN]   = "EEE7EE", -- Skin colour
    [CAP]    = "ffffff",
}


--[[
    Note: If there are some functionalities you don't care
    to add such as palettes, you can freely remove the function
    for it, the only function you require is character_add
]]

local CSloaded = false
local function on_character_select_load()
    CT_CHAR = _G.charSelect.character_add("Pouncer", {"One of Toothless's kids!", "Pouncer is a boy Night Light and unlike his brother", "Ruffrunner and sister Dart, he resambles more of his", "mother Light Fury than Toothless.", "Model from School of Dragons"}, "MrMarco1003", {r = 244, g = 239, b = 244}, E_MODEL_CUSTOM_MODEL, CT_MARIO, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_DART)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHAR, healthToothless)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_DART then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)